@@ -31,6 +31,7 @@
 #include <ctype.h>
 #include <string.h>
 #include <glib/gi18n-lib.h>
+#include <gio/gio.h>
 
 #undef GTK_DISABLE_DEPRECATED /* for GtkOptionMenu */
 #include <gtk/gtk.h>
@@ -39,8 +40,6 @@
 
 #include <libgnomeui/gnome-uidefs.h>
 
-#include <libgnomevfs/gnome-vfs-utils.h>
-
 #undef GNOME_DISABLE_DEPRECATED
 #include <libgnomeui/gnome-icon-entry.h>
 
@@ -1064,7 +1063,6 @@ gnome_ditem_edit_sync_ditem (GnomeDItemEdit *dee)
 	GtkWidget        *entry;
 	const char       *type;
 	const char       *uri;
-	char             *free_uri;
 	const char       *attr;
 	char             *file;
 	gboolean          ret;
@@ -1085,18 +1083,12 @@ gnome_ditem_edit_sync_ditem (GnomeDItemEdit *dee)
 	gnome_desktop_item_set_string (ditem, GNOME_DESKTOP_ITEM_TYPE, type);
 
 	/* hack really */
-	free_uri = NULL;
-	if (type && !strcmp (type, "Link")) {
-		free_uri = gnome_vfs_make_uri_canonical (uri);
-		uri = free_uri;
-
+	if (type && !strcmp (type, "Link"))
 		attr = GNOME_DESKTOP_ITEM_URL;
-	} else
+	else
 		attr  = GNOME_DESKTOP_ITEM_EXEC;
 
 	gnome_desktop_item_set_string (ditem, attr, uri);
-	if (free_uri)
-		g_free (free_uri);
 
 	gnome_desktop_item_set_string (
 		ditem, GNOME_DESKTOP_ITEM_TRY_EXEC,
